| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Pinecone.Backups
Contents
Description
Backups
Synopsis
- newtype Collection = Collection {}
- data Collections = Collections {
- collections :: Vector CollectionModel
- data CreateCollection = CreateCollection {}
- _CreateCollection :: CreateCollection
- data CollectionModel = CollectionModel {
- name :: Collection
- status :: Status
- environment :: Text
- size :: Maybe Natural
- dimension :: Maybe Natural
- vector_count :: Maybe Natural
- data Status
- type API = "collections" :> (Get '[JSON] Collections :<|> ((ReqBody '[JSON] CreateCollection :> Post '[JSON] CollectionModel) :<|> ((Capture "collection_name" Collection :> Get '[JSON] CollectionModel) :<|> (Capture "collection_name" Collection :> DeleteAccepted '[JSON] NoContent))))
Main types
newtype Collection Source #
The name of the collection
Constructors
| Collection | |
Instances
| FromJSON Collection Source # | |
Defined in Pinecone.Backups | |
| ToJSON Collection Source # | |
Defined in Pinecone.Backups Methods toJSON :: Collection -> Value # toEncoding :: Collection -> Encoding # toJSONList :: [Collection] -> Value # toEncodingList :: [Collection] -> Encoding # omitField :: Collection -> Bool # | |
| IsString Collection Source # | |
Defined in Pinecone.Backups Methods fromString :: String -> Collection # | |
| Show Collection Source # | |
Defined in Pinecone.Backups Methods showsPrec :: Int -> Collection -> ShowS # show :: Collection -> String # showList :: [Collection] -> ShowS # | |
| Eq Collection Source # | |
Defined in Pinecone.Backups | |
| ToHttpApiData Collection Source # | |
Defined in Pinecone.Backups Methods toUrlPiece :: Collection -> Text # toEncodedUrlPiece :: Collection -> Builder # toHeader :: Collection -> ByteString # toQueryParam :: Collection -> Text # | |
data Collections Source #
The list of collections that exist in the project.
Constructors
| Collections | |
Fields
| |
Instances
data CreateCollection Source #
The configuration needed to create a Pinecone collection.
Constructors
| CreateCollection | |
Instances
| FromJSON CreateCollection Source # | |||||
Defined in Pinecone.Backups Methods parseJSON :: Value -> Parser CreateCollection # parseJSONList :: Value -> Parser [CreateCollection] # | |||||
| ToJSON CreateCollection Source # | |||||
Defined in Pinecone.Backups Methods toJSON :: CreateCollection -> Value # toEncoding :: CreateCollection -> Encoding # toJSONList :: [CreateCollection] -> Value # toEncodingList :: [CreateCollection] -> Encoding # omitField :: CreateCollection -> Bool # | |||||
| Generic CreateCollection Source # | |||||
Defined in Pinecone.Backups Associated Types
Methods from :: CreateCollection -> Rep CreateCollection x # to :: Rep CreateCollection x -> CreateCollection # | |||||
| Show CreateCollection Source # | |||||
Defined in Pinecone.Backups Methods showsPrec :: Int -> CreateCollection -> ShowS # show :: CreateCollection -> String # showList :: [CreateCollection] -> ShowS # | |||||
| Eq CreateCollection Source # | |||||
Defined in Pinecone.Backups Methods (==) :: CreateCollection -> CreateCollection -> Bool # (/=) :: CreateCollection -> CreateCollection -> Bool # | |||||
| type Rep CreateCollection Source # | |||||
Defined in Pinecone.Backups type Rep CreateCollection = D1 ('MetaData "CreateCollection" "Pinecone.Backups" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "CreateCollection" 'PrefixI 'True) (S1 ('MetaSel ('Just "name") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: S1 ('MetaSel ('Just "source") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Index))) | |||||
_CreateCollection :: CreateCollection Source #
Default CreateCollection
data CollectionModel Source #
The CollectionModel describes the configuration and status of a Pinecone collection.
Constructors
| CollectionModel | |
Fields
| |
Instances
| FromJSON CollectionModel Source # | |||||
Defined in Pinecone.Backups Methods parseJSON :: Value -> Parser CollectionModel # parseJSONList :: Value -> Parser [CollectionModel] # | |||||
| ToJSON CollectionModel Source # | |||||
Defined in Pinecone.Backups Methods toJSON :: CollectionModel -> Value # toEncoding :: CollectionModel -> Encoding # toJSONList :: [CollectionModel] -> Value # toEncodingList :: [CollectionModel] -> Encoding # omitField :: CollectionModel -> Bool # | |||||
| Generic CollectionModel Source # | |||||
Defined in Pinecone.Backups Associated Types
Methods from :: CollectionModel -> Rep CollectionModel x # to :: Rep CollectionModel x -> CollectionModel # | |||||
| Show CollectionModel Source # | |||||
Defined in Pinecone.Backups Methods showsPrec :: Int -> CollectionModel -> ShowS # show :: CollectionModel -> String # showList :: [CollectionModel] -> ShowS # | |||||
| Eq CollectionModel Source # | |||||
Defined in Pinecone.Backups Methods (==) :: CollectionModel -> CollectionModel -> Bool # (/=) :: CollectionModel -> CollectionModel -> Bool # | |||||
| type Rep CollectionModel Source # | |||||
Defined in Pinecone.Backups type Rep CollectionModel = D1 ('MetaData "CollectionModel" "Pinecone.Backups" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "CollectionModel" 'PrefixI 'True) ((S1 ('MetaSel ('Just "name") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Collection) :*: (S1 ('MetaSel ('Just "status") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Status) :*: S1 ('MetaSel ('Just "environment") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "size") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)) :*: (S1 ('MetaSel ('Just "dimension") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)) :*: S1 ('MetaSel ('Just "vector_count") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))))) | |||||
Other types
The status of the operation.
Constructors
| Initializing | |
| Ready | |
| Terminating |
Instances
| FromJSON Status Source # | |||||
Defined in Pinecone.Backups | |||||
| ToJSON Status Source # | |||||
| Generic Status Source # | |||||
Defined in Pinecone.Backups Associated Types
| |||||
| Show Status Source # | |||||
| Eq Status Source # | |||||
| type Rep Status Source # | |||||
Defined in Pinecone.Backups type Rep Status = D1 ('MetaData "Status" "Pinecone.Backups" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "Initializing" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "Ready" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Terminating" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
Servant
type API = "collections" :> (Get '[JSON] Collections :<|> ((ReqBody '[JSON] CreateCollection :> Post '[JSON] CollectionModel) :<|> ((Capture "collection_name" Collection :> Get '[JSON] CollectionModel) :<|> (Capture "collection_name" Collection :> DeleteAccepted '[JSON] NoContent)))) Source #
Servant API