| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Pinecone.Imports
Contents
Description
Imports
Synopsis
- newtype Import = Import {}
- data StartImport = StartImport {}
- _StartImport :: StartImport
- data StartImportResponse = StartImportResponse {}
- data Imports = ListImport {
- data_ :: Vector ImportModel
- pagination :: Maybe Pagination
- data ImportModel = ImportModel {}
- data ErrorMode = ErrorMode {}
- data OnError
- data Status
- type API = "bulk" :> ("imports" :> ((ReqBody '[JSON] StartImport :> Post '[JSON] StartImportResponse) :<|> ((QueryParam "limit" Natural :> (QueryParam "paginationToken" Text :> Get '[JSON] Imports)) :<|> ((Capture "id" Import :> Get '[JSON] ImportModel) :<|> (Capture "id" Import :> Delete '[JSON] NoContent)))))
Main types
Unique identifier for the import operation
Instances
| FromJSON Import Source # | |
Defined in Pinecone.Imports | |
| ToJSON Import Source # | |
| IsString Import Source # | |
Defined in Pinecone.Imports Methods fromString :: String -> Import # | |
| Show Import Source # | |
| Eq Import Source # | |
| ToHttpApiData Import Source # | |
Defined in Pinecone.Imports Methods toUrlPiece :: Import -> Text # toEncodedUrlPiece :: Import -> Builder # toHeader :: Import -> ByteString # toQueryParam :: Import -> Text # toEncodedQueryParam :: Import -> Builder # | |
data StartImport Source #
Request body for /bulk/imports
Constructors
| StartImport | |
Instances
_StartImport :: StartImport Source #
Default StartImport
data StartImportResponse Source #
Response body for /bulk/imports
Constructors
| StartImportResponse | |
Instances
| FromJSON StartImportResponse Source # | |||||
Defined in Pinecone.Imports Methods parseJSON :: Value -> Parser StartImportResponse # parseJSONList :: Value -> Parser [StartImportResponse] # | |||||
| ToJSON StartImportResponse Source # | |||||
Defined in Pinecone.Imports Methods toJSON :: StartImportResponse -> Value # toEncoding :: StartImportResponse -> Encoding # toJSONList :: [StartImportResponse] -> Value # toEncodingList :: [StartImportResponse] -> Encoding # omitField :: StartImportResponse -> Bool # | |||||
| Generic StartImportResponse Source # | |||||
Defined in Pinecone.Imports Associated Types
Methods from :: StartImportResponse -> Rep StartImportResponse x # to :: Rep StartImportResponse x -> StartImportResponse # | |||||
| Show StartImportResponse Source # | |||||
Defined in Pinecone.Imports Methods showsPrec :: Int -> StartImportResponse -> ShowS # show :: StartImportResponse -> String # showList :: [StartImportResponse] -> ShowS # | |||||
| Eq StartImportResponse Source # | |||||
Defined in Pinecone.Imports Methods (==) :: StartImportResponse -> StartImportResponse -> Bool # (/=) :: StartImportResponse -> StartImportResponse -> Bool # | |||||
| type Rep StartImportResponse Source # | |||||
Defined in Pinecone.Imports type Rep StartImportResponse = D1 ('MetaData "StartImportResponse" "Pinecone.Imports" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "StartImportResponse" 'PrefixI 'True) (S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Import))) | |||||
A list of import operations
Constructors
| ListImport | |
Fields
| |
Instances
| FromJSON Imports Source # | |||||
Defined in Pinecone.Imports | |||||
| ToJSON Imports Source # | |||||
| Generic Imports Source # | |||||
Defined in Pinecone.Imports Associated Types
| |||||
| Show Imports Source # | |||||
| Eq Imports Source # | |||||
| type Rep Imports Source # | |||||
Defined in Pinecone.Imports type Rep Imports = D1 ('MetaData "Imports" "Pinecone.Imports" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "ListImport" 'PrefixI 'True) (S1 ('MetaSel ('Just "data_") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Vector ImportModel)) :*: S1 ('MetaSel ('Just "pagination") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Pagination)))) | |||||
data ImportModel Source #
The model for an import operation.
Constructors
| ImportModel | |
Instances
| FromJSON ImportModel Source # | |||||
Defined in Pinecone.Imports | |||||
| ToJSON ImportModel Source # | |||||
Defined in Pinecone.Imports Methods toJSON :: ImportModel -> Value # toEncoding :: ImportModel -> Encoding # toJSONList :: [ImportModel] -> Value # toEncodingList :: [ImportModel] -> Encoding # omitField :: ImportModel -> Bool # | |||||
| Generic ImportModel Source # | |||||
Defined in Pinecone.Imports Associated Types
| |||||
| Show ImportModel Source # | |||||
Defined in Pinecone.Imports Methods showsPrec :: Int -> ImportModel -> ShowS # show :: ImportModel -> String # showList :: [ImportModel] -> ShowS # | |||||
| Eq ImportModel Source # | |||||
Defined in Pinecone.Imports | |||||
| type Rep ImportModel Source # | |||||
Defined in Pinecone.Imports type Rep ImportModel = D1 ('MetaData "ImportModel" "Pinecone.Imports" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "ImportModel" 'PrefixI 'True) (((S1 ('MetaSel ('Just "id") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Import) :*: S1 ('MetaSel ('Just "uri") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text)) :*: (S1 ('MetaSel ('Just "status") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Status) :*: S1 ('MetaSel ('Just "createdAt") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 POSIXTime))) :*: ((S1 ('MetaSel ('Just "finishedAt") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 POSIXTime) :*: S1 ('MetaSel ('Just "percentComplete") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)) :*: (S1 ('MetaSel ('Just "recordsImported") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Natural) :*: S1 ('MetaSel ('Just "error") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))))) | |||||
Other types
Indicates how to respond to errors during the import process.
Instances
| FromJSON ErrorMode Source # | |||||
Defined in Pinecone.Imports | |||||
| ToJSON ErrorMode Source # | |||||
| Generic ErrorMode Source # | |||||
Defined in Pinecone.Imports Associated Types
| |||||
| Show ErrorMode Source # | |||||
| Eq ErrorMode Source # | |||||
| type Rep ErrorMode Source # | |||||
Defined in Pinecone.Imports | |||||
Indicates how to respond to errors during the import process.
The status of the operation.
Constructors
| Pending | |
| InProgress | |
| Failed | |
| Completed | |
| Cancelled |
Instances
| FromJSON Status Source # | |||||
Defined in Pinecone.Imports | |||||
| ToJSON Status Source # | |||||
| Generic Status Source # | |||||
Defined in Pinecone.Imports Associated Types
| |||||
| Show Status Source # | |||||
| Eq Status Source # | |||||
| type Rep Status Source # | |||||
Defined in Pinecone.Imports type Rep Status = D1 ('MetaData "Status" "Pinecone.Imports" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) ((C1 ('MetaCons "Pending" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "InProgress" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "Failed" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "Completed" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Cancelled" 'PrefixI 'False) (U1 :: Type -> Type)))) | |||||
Servant
type API = "bulk" :> ("imports" :> ((ReqBody '[JSON] StartImport :> Post '[JSON] StartImportResponse) :<|> ((QueryParam "limit" Natural :> (QueryParam "paginationToken" Text :> Get '[JSON] Imports)) :<|> ((Capture "id" Import :> Get '[JSON] ImportModel) :<|> (Capture "id" Import :> Delete '[JSON] NoContent))))) Source #
Servant API