| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Pinecone.Indexes
Contents
Description
Indexes
Synopsis
- newtype Index = Index {}
- newtype Host = Host {}
- data IndexModels = IndexModels {
- indexes :: Vector IndexModel
- data IndexModel = IndexModel {}
- data CreateIndex = CreateIndex {}
- _CreateIndex :: CreateIndex
- data CreateIndexWithEmbedding = CreateIndexWithEmbedding {}
- _CreateIndexWithEmbedding :: CreateIndexWithEmbedding
- data ConfigureIndex = ConfigureIndex {}
- _ConfigureIndex :: ConfigureIndex
- data GetIndexStats = GetIndexStats {}
- _GetIndexStats :: GetIndexStats
- data IndexStats = IndexStats {}
- data Metric
- data Spec = Spec {
- pod :: Maybe Pod
- serverless :: Maybe Serverless
- data Pod = Pod {}
- data PodType = PodType {}
- data Prefix
- data Suffix
- data MetadataConfig = MetadataConfig {}
- data Serverless = Serverless {}
- data Cloud
- data Status = Status {}
- data State
- data DeletionProtection
- data EmbedRequest = EmbedRequest {}
- data EmbedResponse = EmbedResponse {}
- data Contents = Contents {}
- type ControlAPI = "indexes" :> (Get '[JSON] IndexModels :<|> ((ReqBody '[JSON] CreateIndex :> Post '[JSON] IndexModel) :<|> (("create-for-model" :> (ReqBody '[JSON] CreateIndexWithEmbedding :> PostCreated '[JSON] IndexModel)) :<|> ((Capture "index_name" Index :> Get '[JSON] IndexModel) :<|> ((Capture "index_name" Index :> DeleteAccepted '[JSON] NoContent) :<|> (Capture "index_name" Index :> (ReqBody '[JSON] ConfigureIndex :> Patch '[JSON] IndexModel)))))))
- type DataAPI = "describe_index_stats" :> (ReqBody '[JSON] GetIndexStats :> Post '[JSON] IndexStats)
Main types
The name of the index
Instances
| FromJSON Index Source # | |
Defined in Pinecone.Indexes | |
| ToJSON Index Source # | |
| IsString Index Source # | |
Defined in Pinecone.Indexes Methods fromString :: String -> Index # | |
| Show Index Source # | |
| Eq Index Source # | |
| ToHttpApiData Index Source # | |
Defined in Pinecone.Indexes Methods toUrlPiece :: Index -> Text # toEncodedUrlPiece :: Index -> Builder # toHeader :: Index -> ByteString # toQueryParam :: Index -> Text # toEncodedQueryParam :: Index -> Builder # | |
The host for the index
Instances
| FromJSON Host Source # | |
Defined in Pinecone.Indexes | |
| ToJSON Host Source # | |
| IsString Host Source # | |
Defined in Pinecone.Indexes Methods fromString :: String -> Host # | |
| Show Host Source # | |
| Eq Host Source # | |
| ToHttpApiData Host Source # | |
Defined in Pinecone.Indexes Methods toUrlPiece :: Host -> Text # toEncodedUrlPiece :: Host -> Builder # toHeader :: Host -> ByteString # toQueryParam :: Host -> Text # toEncodedQueryParam :: Host -> Builder # | |
data IndexModels Source #
The list of indexes that exist in the project
Constructors
| IndexModels | |
Fields
| |
Instances
data IndexModel Source #
The IndexModel describes the configuration and status of a Pinecone
index
Constructors
| IndexModel | |
Instances
| FromJSON IndexModel Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON IndexModel Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: IndexModel -> Value # toEncoding :: IndexModel -> Encoding # toJSONList :: [IndexModel] -> Value # toEncodingList :: [IndexModel] -> Encoding # omitField :: IndexModel -> Bool # | |||||
| Generic IndexModel Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show IndexModel Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> IndexModel -> ShowS # show :: IndexModel -> String # showList :: [IndexModel] -> ShowS # | |||||
| Eq IndexModel Source # | |||||
Defined in Pinecone.Indexes | |||||
| type Rep IndexModel Source # | |||||
Defined in Pinecone.Indexes type Rep IndexModel = D1 ('MetaData "IndexModel" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "IndexModel" 'PrefixI 'True) (((S1 ('MetaSel ('Just "name") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Index) :*: S1 ('MetaSel ('Just "metric") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Metric)) :*: (S1 ('MetaSel ('Just "host") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Host) :*: (S1 ('MetaSel ('Just "spec") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Spec) :*: S1 ('MetaSel ('Just "status") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Status)))) :*: ((S1 ('MetaSel ('Just "vector_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 VectorType) :*: S1 ('MetaSel ('Just "dimension") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural))) :*: (S1 ('MetaSel ('Just "deletion_protection") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe DeletionProtection)) :*: (S1 ('MetaSel ('Just "tags") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Text))) :*: S1 ('MetaSel ('Just "embed") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe EmbedResponse))))))) | |||||
data CreateIndex Source #
The desired configuration for the index
Constructors
| CreateIndex | |
Instances
| FromJSON CreateIndex Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON CreateIndex Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: CreateIndex -> Value # toEncoding :: CreateIndex -> Encoding # toJSONList :: [CreateIndex] -> Value # toEncodingList :: [CreateIndex] -> Encoding # omitField :: CreateIndex -> Bool # | |||||
| Generic CreateIndex Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show CreateIndex Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> CreateIndex -> ShowS # show :: CreateIndex -> String # showList :: [CreateIndex] -> ShowS # | |||||
| Eq CreateIndex Source # | |||||
Defined in Pinecone.Indexes | |||||
| type Rep CreateIndex Source # | |||||
Defined in Pinecone.Indexes type Rep CreateIndex = D1 ('MetaData "CreateIndex" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "CreateIndex" 'PrefixI 'True) ((S1 ('MetaSel ('Just "name") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Index) :*: (S1 ('MetaSel ('Just "spec") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Spec) :*: S1 ('MetaSel ('Just "dimension") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))) :*: ((S1 ('MetaSel ('Just "metric") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Metric)) :*: S1 ('MetaSel ('Just "deletion_protection") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe DeletionProtection))) :*: (S1 ('MetaSel ('Just "tags") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Text))) :*: S1 ('MetaSel ('Just "vector_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe VectorType)))))) | |||||
_CreateIndex :: CreateIndex Source #
Default CreateIndex
data CreateIndexWithEmbedding Source #
The desired configuration for the index and associated embedding model
Constructors
| CreateIndexWithEmbedding | |
Instances
| FromJSON CreateIndexWithEmbedding Source # | |||||
Defined in Pinecone.Indexes Methods parseJSON :: Value -> Parser CreateIndexWithEmbedding # parseJSONList :: Value -> Parser [CreateIndexWithEmbedding] # | |||||
| ToJSON CreateIndexWithEmbedding Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: CreateIndexWithEmbedding -> Value # toEncoding :: CreateIndexWithEmbedding -> Encoding # toJSONList :: [CreateIndexWithEmbedding] -> Value # | |||||
| Generic CreateIndexWithEmbedding Source # | |||||
Defined in Pinecone.Indexes Associated Types
Methods from :: CreateIndexWithEmbedding -> Rep CreateIndexWithEmbedding x # to :: Rep CreateIndexWithEmbedding x -> CreateIndexWithEmbedding # | |||||
| Show CreateIndexWithEmbedding Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> CreateIndexWithEmbedding -> ShowS # show :: CreateIndexWithEmbedding -> String # showList :: [CreateIndexWithEmbedding] -> ShowS # | |||||
| Eq CreateIndexWithEmbedding Source # | |||||
Defined in Pinecone.Indexes Methods (==) :: CreateIndexWithEmbedding -> CreateIndexWithEmbedding -> Bool # (/=) :: CreateIndexWithEmbedding -> CreateIndexWithEmbedding -> Bool # | |||||
| type Rep CreateIndexWithEmbedding Source # | |||||
Defined in Pinecone.Indexes type Rep CreateIndexWithEmbedding = D1 ('MetaData "CreateIndexWithEmbedding" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "CreateIndexWithEmbedding" 'PrefixI 'True) ((S1 ('MetaSel ('Just "name") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Index) :*: (S1 ('MetaSel ('Just "cloud") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Cloud) :*: S1 ('MetaSel ('Just "region") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "embed") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 EmbedRequest) :*: (S1 ('MetaSel ('Just "deletion_protection") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe DeletionProtection)) :*: S1 ('MetaSel ('Just "tags") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Text))))))) | |||||
data ConfigureIndex Source #
The desired pod size and replica configuration for the index
Constructors
| ConfigureIndex | |
Fields
| |
Instances
| FromJSON ConfigureIndex Source # | |||||
Defined in Pinecone.Indexes Methods parseJSON :: Value -> Parser ConfigureIndex # parseJSONList :: Value -> Parser [ConfigureIndex] # | |||||
| ToJSON ConfigureIndex Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: ConfigureIndex -> Value # toEncoding :: ConfigureIndex -> Encoding # toJSONList :: [ConfigureIndex] -> Value # toEncodingList :: [ConfigureIndex] -> Encoding # omitField :: ConfigureIndex -> Bool # | |||||
| Generic ConfigureIndex Source # | |||||
Defined in Pinecone.Indexes Associated Types
Methods from :: ConfigureIndex -> Rep ConfigureIndex x # to :: Rep ConfigureIndex x -> ConfigureIndex # | |||||
| Show ConfigureIndex Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> ConfigureIndex -> ShowS # show :: ConfigureIndex -> String # showList :: [ConfigureIndex] -> ShowS # | |||||
| Eq ConfigureIndex Source # | |||||
Defined in Pinecone.Indexes Methods (==) :: ConfigureIndex -> ConfigureIndex -> Bool # (/=) :: ConfigureIndex -> ConfigureIndex -> Bool # | |||||
| type Rep ConfigureIndex Source # | |||||
Defined in Pinecone.Indexes type Rep ConfigureIndex = D1 ('MetaData "ConfigureIndex" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "ConfigureIndex" 'PrefixI 'True) ((S1 ('MetaSel ('Just "spec") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Spec)) :*: S1 ('MetaSel ('Just "deletion_protection") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe DeletionProtection))) :*: (S1 ('MetaSel ('Just "tags") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Text))) :*: S1 ('MetaSel ('Just "embed") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe EmbedRequest))))) | |||||
_ConfigureIndex :: ConfigureIndex Source #
Default ConfigureIndex
data GetIndexStats Source #
Request body for /describe_index_stats
Constructors
| GetIndexStats | |
Instances
| FromJSON GetIndexStats Source # | |||||
Defined in Pinecone.Indexes Methods parseJSON :: Value -> Parser GetIndexStats # parseJSONList :: Value -> Parser [GetIndexStats] # | |||||
| ToJSON GetIndexStats Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: GetIndexStats -> Value # toEncoding :: GetIndexStats -> Encoding # toJSONList :: [GetIndexStats] -> Value # toEncodingList :: [GetIndexStats] -> Encoding # omitField :: GetIndexStats -> Bool # | |||||
| Generic GetIndexStats Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show GetIndexStats Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> GetIndexStats -> ShowS # show :: GetIndexStats -> String # showList :: [GetIndexStats] -> ShowS # | |||||
| Eq GetIndexStats Source # | |||||
Defined in Pinecone.Indexes Methods (==) :: GetIndexStats -> GetIndexStats -> Bool # (/=) :: GetIndexStats -> GetIndexStats -> Bool # | |||||
| type Rep GetIndexStats Source # | |||||
Defined in Pinecone.Indexes type Rep GetIndexStats = D1 ('MetaData "GetIndexStats" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "GetIndexStats" 'PrefixI 'True) (S1 ('MetaSel ('Just "filter") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Filter)))) | |||||
_GetIndexStats :: GetIndexStats Source #
Default GetIndexStats
data IndexStats Source #
Response body for /describe_index_stats
Constructors
| IndexStats | |
Fields
| |
Instances
| FromJSON IndexStats Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON IndexStats Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: IndexStats -> Value # toEncoding :: IndexStats -> Encoding # toJSONList :: [IndexStats] -> Value # toEncodingList :: [IndexStats] -> Encoding # omitField :: IndexStats -> Bool # | |||||
| Generic IndexStats Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show IndexStats Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> IndexStats -> ShowS # show :: IndexStats -> String # showList :: [IndexStats] -> ShowS # | |||||
| Eq IndexStats Source # | |||||
Defined in Pinecone.Indexes | |||||
| type Rep IndexStats Source # | |||||
Defined in Pinecone.Indexes type Rep IndexStats = D1 ('MetaData "IndexStats" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "IndexStats" 'PrefixI 'True) ((S1 ('MetaSel ('Just "namespaces") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Map Text Contents)) :*: (S1 ('MetaSel ('Just "dimension") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Natural) :*: S1 ('MetaSel ('Just "indexFullness") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double))) :*: (S1 ('MetaSel ('Just "totalVectorCount") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Natural) :*: (S1 ('MetaSel ('Just "metric") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Metric) :*: S1 ('MetaSel ('Just "vectorType") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 VectorType))))) | |||||
Other types
The distance metric to be used for similarity search
Constructors
| Cosine | |
| Euclidean | |
| DotProduct |
Instances
| FromJSON Metric Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON Metric Source # | |||||
| Generic Metric Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show Metric Source # | |||||
| Eq Metric Source # | |||||
| type Rep Metric Source # | |||||
Defined in Pinecone.Indexes type Rep Metric = D1 ('MetaData "Metric" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "Cosine" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "Euclidean" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "DotProduct" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
Spec object
Constructors
| Spec | |
Fields
| |
Instances
| FromJSON Spec Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON Spec Source # | |||||
| Generic Spec Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show Spec Source # | |||||
| Eq Spec Source # | |||||
| type Rep Spec Source # | |||||
Defined in Pinecone.Indexes type Rep Spec = D1 ('MetaData "Spec" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "Spec" 'PrefixI 'True) (S1 ('MetaSel ('Just "pod") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Pod)) :*: S1 ('MetaSel ('Just "serverless") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Serverless)))) | |||||
Configuration needed to deploy a pod-based index.
Constructors
| Pod | |
Fields
| |
Instances
| FromJSON Pod Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON Pod Source # | |||||
| Generic Pod Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show Pod Source # | |||||
| Eq Pod Source # | |||||
| type Rep Pod Source # | |||||
Defined in Pinecone.Indexes type Rep Pod = D1 ('MetaData "Pod" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "Pod" 'PrefixI 'True) ((S1 ('MetaSel ('Just "environment") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: (S1 ('MetaSel ('Just "pod_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 PodType) :*: S1 ('MetaSel ('Just "replicas") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))) :*: ((S1 ('MetaSel ('Just "shards") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)) :*: S1 ('MetaSel ('Just "pods") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural))) :*: (S1 ('MetaSel ('Just "metadata_config") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe MetadataConfig)) :*: S1 ('MetaSel ('Just "source_collection") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Text)))))) | |||||
The type of pod to use
Instances
| FromJSON PodType Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON PodType Source # | |||||
| Generic PodType Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show PodType Source # | |||||
| Eq PodType Source # | |||||
| type Rep PodType Source # | |||||
Defined in Pinecone.Indexes type Rep PodType = D1 ('MetaData "PodType" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "PodType" 'PrefixI 'True) (S1 ('MetaSel ('Just "prefix") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Prefix) :*: S1 ('MetaSel ('Just "suffix") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Suffix))) | |||||
The first component of a pod type
The second component of a pod type
Instances
| FromJSON Suffix Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON Suffix Source # | |||||
| Generic Suffix Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show Suffix Source # | |||||
| Eq Suffix Source # | |||||
| type Rep Suffix Source # | |||||
Defined in Pinecone.Indexes type Rep Suffix = D1 ('MetaData "Suffix" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) ((C1 ('MetaCons "X1" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "X2" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "X4" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "X8" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
data MetadataConfig Source #
Configuration for the behavior of Pinecone's internal metadata index
Constructors
| MetadataConfig | |
Instances
| FromJSON MetadataConfig Source # | |||||
Defined in Pinecone.Indexes Methods parseJSON :: Value -> Parser MetadataConfig # parseJSONList :: Value -> Parser [MetadataConfig] # | |||||
| ToJSON MetadataConfig Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: MetadataConfig -> Value # toEncoding :: MetadataConfig -> Encoding # toJSONList :: [MetadataConfig] -> Value # toEncodingList :: [MetadataConfig] -> Encoding # omitField :: MetadataConfig -> Bool # | |||||
| Generic MetadataConfig Source # | |||||
Defined in Pinecone.Indexes Associated Types
Methods from :: MetadataConfig -> Rep MetadataConfig x # to :: Rep MetadataConfig x -> MetadataConfig # | |||||
| Show MetadataConfig Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> MetadataConfig -> ShowS # show :: MetadataConfig -> String # showList :: [MetadataConfig] -> ShowS # | |||||
| Eq MetadataConfig Source # | |||||
Defined in Pinecone.Indexes Methods (==) :: MetadataConfig -> MetadataConfig -> Bool # (/=) :: MetadataConfig -> MetadataConfig -> Bool # | |||||
| type Rep MetadataConfig Source # | |||||
Defined in Pinecone.Indexes type Rep MetadataConfig = D1 ('MetaData "MetadataConfig" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "MetadataConfig" 'PrefixI 'True) (S1 ('MetaSel ('Just "indexed") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Vector Text))))) | |||||
data Serverless Source #
Configuration needed to deploy a serverless index
Constructors
| Serverless | |
Instances
| FromJSON Serverless Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON Serverless Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: Serverless -> Value # toEncoding :: Serverless -> Encoding # toJSONList :: [Serverless] -> Value # toEncodingList :: [Serverless] -> Encoding # omitField :: Serverless -> Bool # | |||||
| Generic Serverless Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show Serverless Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> Serverless -> ShowS # show :: Serverless -> String # showList :: [Serverless] -> ShowS # | |||||
| Eq Serverless Source # | |||||
Defined in Pinecone.Indexes | |||||
| type Rep Serverless Source # | |||||
Defined in Pinecone.Indexes type Rep Serverless = D1 ('MetaData "Serverless" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "Serverless" 'PrefixI 'True) (S1 ('MetaSel ('Just "cloud") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Cloud) :*: S1 ('MetaSel ('Just "region") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
The public cloud where you would like your index hosted
Index status
Instances
| FromJSON Status Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON Status Source # | |||||
| Generic Status Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show Status Source # | |||||
| Eq Status Source # | |||||
| type Rep Status Source # | |||||
Defined in Pinecone.Indexes type Rep Status = D1 ('MetaData "Status" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "Status" 'PrefixI 'True) (S1 ('MetaSel ('Just "ready") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Bool) :*: S1 ('MetaSel ('Just "state") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 State))) | |||||
Index state
Constructors
| Initializing | |
| InitializationFailed | |
| ScalingUp | |
| ScalingDown | |
| ScalingUpPodSize | |
| ScalingDownPodSize | |
| Terminating | |
| Ready |
Instances
| FromJSON State Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON State Source # | |||||
| Generic State Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show State Source # | |||||
| Eq State Source # | |||||
| type Rep State Source # | |||||
Defined in Pinecone.Indexes type Rep State = D1 ('MetaData "State" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (((C1 ('MetaCons "Initializing" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "InitializationFailed" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "ScalingUp" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "ScalingDown" 'PrefixI 'False) (U1 :: Type -> Type))) :+: ((C1 ('MetaCons "ScalingUpPodSize" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "ScalingDownPodSize" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "Terminating" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Ready" 'PrefixI 'False) (U1 :: Type -> Type)))) | |||||
data DeletionProtection Source #
Whether deletion protection is enabled/disabled for the index.
Instances
| FromJSON DeletionProtection Source # | |||||
Defined in Pinecone.Indexes Methods parseJSON :: Value -> Parser DeletionProtection # parseJSONList :: Value -> Parser [DeletionProtection] # | |||||
| ToJSON DeletionProtection Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: DeletionProtection -> Value # toEncoding :: DeletionProtection -> Encoding # toJSONList :: [DeletionProtection] -> Value # toEncodingList :: [DeletionProtection] -> Encoding # omitField :: DeletionProtection -> Bool # | |||||
| Generic DeletionProtection Source # | |||||
Defined in Pinecone.Indexes Associated Types
Methods from :: DeletionProtection -> Rep DeletionProtection x # to :: Rep DeletionProtection x -> DeletionProtection # | |||||
| Show DeletionProtection Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> DeletionProtection -> ShowS # show :: DeletionProtection -> String # showList :: [DeletionProtection] -> ShowS # | |||||
| Eq DeletionProtection Source # | |||||
Defined in Pinecone.Indexes Methods (==) :: DeletionProtection -> DeletionProtection -> Bool # (/=) :: DeletionProtection -> DeletionProtection -> Bool # | |||||
| type Rep DeletionProtection Source # | |||||
data EmbedRequest Source #
Specify the integrated inference embedding configuration for the index
Constructors
| EmbedRequest | |
Instances
| FromJSON EmbedRequest Source # | |||||
Defined in Pinecone.Indexes | |||||
| ToJSON EmbedRequest Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: EmbedRequest -> Value # toEncoding :: EmbedRequest -> Encoding # toJSONList :: [EmbedRequest] -> Value # toEncodingList :: [EmbedRequest] -> Encoding # omitField :: EmbedRequest -> Bool # | |||||
| Generic EmbedRequest Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show EmbedRequest Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> EmbedRequest -> ShowS # show :: EmbedRequest -> String # showList :: [EmbedRequest] -> ShowS # | |||||
| Eq EmbedRequest Source # | |||||
Defined in Pinecone.Indexes | |||||
| type Rep EmbedRequest Source # | |||||
Defined in Pinecone.Indexes type Rep EmbedRequest = D1 ('MetaData "EmbedRequest" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "EmbedRequest" 'PrefixI 'True) ((S1 ('MetaSel ('Just "model") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: S1 ('MetaSel ('Just "metric") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Metric))) :*: (S1 ('MetaSel ('Just "read_parameters") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Value))) :*: S1 ('MetaSel ('Just "write_parameters") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Value)))))) | |||||
data EmbedResponse Source #
The embedding model and document fields mapped to embedding inputs
Constructors
| EmbedResponse | |
Instances
| FromJSON EmbedResponse Source # | |||||
Defined in Pinecone.Indexes Methods parseJSON :: Value -> Parser EmbedResponse # parseJSONList :: Value -> Parser [EmbedResponse] # | |||||
| ToJSON EmbedResponse Source # | |||||
Defined in Pinecone.Indexes Methods toJSON :: EmbedResponse -> Value # toEncoding :: EmbedResponse -> Encoding # toJSONList :: [EmbedResponse] -> Value # toEncodingList :: [EmbedResponse] -> Encoding # omitField :: EmbedResponse -> Bool # | |||||
| Generic EmbedResponse Source # | |||||
Defined in Pinecone.Indexes Associated Types
| |||||
| Show EmbedResponse Source # | |||||
Defined in Pinecone.Indexes Methods showsPrec :: Int -> EmbedResponse -> ShowS # show :: EmbedResponse -> String # showList :: [EmbedResponse] -> ShowS # | |||||
| Eq EmbedResponse Source # | |||||
Defined in Pinecone.Indexes Methods (==) :: EmbedResponse -> EmbedResponse -> Bool # (/=) :: EmbedResponse -> EmbedResponse -> Bool # | |||||
| type Rep EmbedResponse Source # | |||||
Defined in Pinecone.Indexes type Rep EmbedResponse = D1 ('MetaData "EmbedResponse" "Pinecone.Indexes" "pinecone-1.0.0-FtIUEL1n6VI5sRXEYSiB7n" 'False) (C1 ('MetaCons "EmbedResponse" 'PrefixI 'True) ((S1 ('MetaSel ('Just "model") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text) :*: (S1 ('MetaSel ('Just "metric") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Metric)) :*: S1 ('MetaSel ('Just "dimension") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe Natural)))) :*: ((S1 ('MetaSel ('Just "vector_type") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe VectorType)) :*: S1 ('MetaSel ('Just "field_map") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Text)))) :*: (S1 ('MetaSel ('Just "read_parameters") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Value))) :*: S1 ('MetaSel ('Just "write_parameters") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Maybe (Map Text Value))))))) | |||||
A summary of the contents of a namespace
Constructors
| Contents | |
Fields | |
Instances
API
type ControlAPI = "indexes" :> (Get '[JSON] IndexModels :<|> ((ReqBody '[JSON] CreateIndex :> Post '[JSON] IndexModel) :<|> (("create-for-model" :> (ReqBody '[JSON] CreateIndexWithEmbedding :> PostCreated '[JSON] IndexModel)) :<|> ((Capture "index_name" Index :> Get '[JSON] IndexModel) :<|> ((Capture "index_name" Index :> DeleteAccepted '[JSON] NoContent) :<|> (Capture "index_name" Index :> (ReqBody '[JSON] ConfigureIndex :> Patch '[JSON] IndexModel))))))) Source #
Control API